@@ -12,23 +12,25 @@ from xp.services.homekit.homekit_service import HomeKitService
 @homekit.command("start")
 @click.pass_context
 def homekit_start(ctx: Context) -> None:
-    """
-    Start the HomeKit server.
+    r"""Start the HomeKit server.
 
     This command starts the XP Protocol HomeKit server using HAP-python.
     The server provides HomeKit endpoints for Conbus operations.
 
-    Examples:
+    Args:
+        ctx: Click context object.
 
-    \b
+    Examples:
+        \b
         # Start server on default host and port
         xp homekit start
-
     """
     click.echo("Starting XP Protocol HomeKit server...")
 
     try:
-        service = ctx.obj.get("container").get_container().resolve(HomeKitService)
+        service: HomeKitService = (
+            ctx.obj.get("container").get_container().resolve(HomeKitService)
+        )
         service.start()  # Blocking call - reactor.run() never returns
 
     except KeyboardInterrupt:
