@@ -1,22 +1,22 @@
-"""
-Connection-related exceptions for XP CLI tool.
+"""Connection-related exceptions for XP CLI tool.
+
 Following the architecture requirement for structured error handling.
 """
 
 
 class XPError(Exception):
-    """Base exception for XP CLI tool"""
+    """Base exception for XP CLI tool."""
 
     pass
 
 
 class ProtocolError(XPError):
-    """Console bus protocol errors"""
+    """Console bus protocol errors."""
 
     pass
 
 
 class ValidationError(XPError):
-    """Input validation errors"""
+    """Input validation errors."""
 
     pass
