@@ -1,3 +1,5 @@
+"""Conbus output response model."""
+
 from dataclasses import dataclass
 from datetime import datetime
 from typing import Any, Dict, Optional
@@ -9,7 +11,20 @@ from xp.models.telegram.reply_telegram import ReplyTelegram
 
 @dataclass
 class ConbusOutputResponse:
-    """Represents a response from Conbus send operation"""
+    """Represents a response from Conbus send operation.
+
+    Attributes:
+        success: Whether the operation was successful.
+        serial_number: Serial number of the device.
+        output_number: Output number controlled.
+        action_type: Type of action performed.
+        timestamp: Timestamp of the response.
+        output_telegram: Output telegram sent.
+        sent_telegram: Raw telegram sent to device.
+        received_telegrams: List of telegrams received.
+        datapoint_telegram: Datapoint telegram received.
+        error: Error message if operation failed.
+    """
 
     success: bool
     serial_number: str
@@ -23,11 +38,16 @@ class ConbusOutputResponse:
     error: Optional[str] = None
 
     def __post_init__(self) -> None:
+        """Initialize received_telegrams if not provided."""
         if self.received_telegrams is None:
             self.received_telegrams = []
 
     def to_dict(self) -> Dict[str, Any]:
-        """Convert to dictionary for JSON serialization"""
+        """Convert to dictionary for JSON serialization.
+
+        Returns:
+            Dictionary representation of the response.
+        """
         return {
             "success": self.success,
             "sent_telegram": self.sent_telegram,
