@@ -7,10 +7,11 @@ from xp.models.protocol.conbus_protocol import (
     ModuleDiscoveredEvent,
     TelegramReceivedEvent,
 )
+from xp.services.protocol.conbus_event_protocol import ConbusEventProtocol
 from xp.services.protocol.conbus_protocol import ConbusProtocol
 from xp.services.protocol.telegram_protocol import TelegramProtocol
 
-__all__ = ["TelegramProtocol", "ConbusProtocol"]
+__all__ = ["TelegramProtocol", "ConbusProtocol", "ConbusEventProtocol"]
 
 # Rebuild models after TelegramProtocol and ConbusProtocol are imported to resolve forward references
 ConnectionMadeEvent.model_rebuild()
