@@ -7,6 +7,7 @@ from twisted.internet.interfaces import IConnector
 from twisted.internet.posixbase import PosixReactorBase
 
 from xp.models import ConbusClientConfig
+from xp.models.conbus.conbus_logger_config import ConbusLoggerConfig
 from xp.models.homekit.homekit_config import HomekitConfig
 from xp.models.homekit.homekit_conson_config import ConsonModuleListConfig
 from xp.services.actiontable.actiontable_serializer import ActionTableSerializer
@@ -43,6 +44,8 @@ from xp.services.conbus.conbus_datapoint_service import (
     ConbusDatapointService,
 )
 from xp.services.conbus.conbus_discover_service import ConbusDiscoverService
+from xp.services.conbus.conbus_event_list_service import ConbusEventListService
+from xp.services.conbus.conbus_event_raw_service import ConbusEventRawService
 from xp.services.conbus.conbus_output_service import ConbusOutputService
 from xp.services.conbus.conbus_raw_service import ConbusRawService
 from xp.services.conbus.conbus_receive_service import ConbusReceiveService
@@ -58,16 +61,19 @@ from xp.services.homekit.homekit_outlet_service import HomeKitOutletService
 from xp.services.homekit.homekit_service import HomeKitService
 from xp.services.log_file_service import LogFileService
 from xp.services.module_type_service import ModuleTypeService
+from xp.services.protocol import ConbusEventProtocol
 from xp.services.protocol.protocol_factory import TelegramFactory
 from xp.services.protocol.telegram_protocol import TelegramProtocol
 from xp.services.reverse_proxy_service import ReverseProxyService
 from xp.services.server.device_service_factory import DeviceServiceFactory
 from xp.services.server.server_service import ServerService
 from xp.services.telegram.telegram_blink_service import TelegramBlinkService
+from xp.services.telegram.telegram_datapoint_service import TelegramDatapointService
 from xp.services.telegram.telegram_discover_service import TelegramDiscoverService
 from xp.services.telegram.telegram_link_number_service import LinkNumberService
 from xp.services.telegram.telegram_output_service import TelegramOutputService
 from xp.services.telegram.telegram_service import TelegramService
+from xp.utils.logging import LoggerService
 
 asyncioreactor.install()
 from twisted.internet import reactor  # noqa: E402
@@ -83,7 +89,8 @@ class ServiceContainer:
 
     def __init__(
         self,
-        config_path: str = "cli.yml",
+        client_config_path: str = "cli.yml",
+        logger_config_path: str = "logger.yml",
         homekit_config_path: str = "homekit.yml",
         conson_config_path: str = "conson.yml",
         server_port: int = 10001,
@@ -93,14 +100,16 @@ class ServiceContainer:
         Initialize the service container.
 
         Args:
-            config_path: Path to the Conbus CLI configuration file
+            client_config_path: Path to the Conbus CLI configuration file
+            logger_config_path: Path to the Conbus Loggerr configuration file
             homekit_config_path: Path to the HomeKit configuration file
             conson_config_path: Path to the Conson configuration file
             server_port: Port for the server service
             reverse_proxy_port: Port for the reverse proxy service
         """
         self.container = punq.Container()
-        self._config_path = config_path
+        self._client_config_path = client_config_path
+        self._logger_config_path = logger_config_path
         self._homekit_config_path = homekit_config_path
         self._conson_config_path = conson_config_path
         self._server_port = server_port
@@ -113,7 +122,13 @@ class ServiceContainer:
         # ConbusClientConfig
         self.container.register(
             ConbusClientConfig,
-            factory=lambda: ConbusClientConfig.from_yaml(self._config_path),
+            factory=lambda: ConbusClientConfig.from_yaml(self._client_config_path),
+            scope=punq.Scope.singleton,
+        )
+
+        self.container.register(
+            ConbusLoggerConfig,
+            factory=lambda: ConbusLoggerConfig.from_yaml(self._logger_config_path),
             scope=punq.Scope.singleton,
         )
 
@@ -128,6 +143,7 @@ class ServiceContainer:
         )
         self.container.register(TelegramDiscoverService, scope=punq.Scope.singleton)
         self.container.register(TelegramBlinkService, scope=punq.Scope.singleton)
+        self.container.register(TelegramDatapointService, scope=punq.Scope.singleton)
         self.container.register(LinkNumberService, scope=punq.Scope.singleton)
 
         # Conbus services layer
@@ -161,14 +177,38 @@ class ServiceContainer:
         )
 
         self.container.register(
-            ConbusDiscoverService,
-            factory=lambda: ConbusDiscoverService(
+            ConbusEventProtocol,
+            factory=lambda: ConbusEventProtocol(
                 cli_config=self.container.resolve(ConbusClientConfig),
                 reactor=self.container.resolve(PosixReactorBase),
             ),
             scope=punq.Scope.singleton,
         )
 
+        self.container.register(
+            ConbusDiscoverService,
+            factory=lambda: ConbusDiscoverService(
+                conbus_protocol=self.container.resolve(ConbusEventProtocol)
+            ),
+            scope=punq.Scope.singleton,
+        )
+
+        self.container.register(
+            ConbusEventRawService,
+            factory=lambda: ConbusEventRawService(
+                conbus_protocol=self.container.resolve(ConbusEventProtocol)
+            ),
+            scope=punq.Scope.singleton,
+        )
+
+        self.container.register(
+            ConbusEventListService,
+            factory=lambda: ConbusEventListService(
+                conson_config=self.container.resolve(ConsonModuleListConfig)
+            ),
+            scope=punq.Scope.singleton,
+        )
+
         self.container.register(
             ConbusBlinkService,
             factory=lambda: ConbusBlinkService(
@@ -303,8 +343,7 @@ class ServiceContainer:
         self.container.register(
             ConbusReceiveService,
             factory=lambda: ConbusReceiveService(
-                cli_config=self.container.resolve(ConbusClientConfig),
-                reactor=self.container.resolve(PosixReactorBase),
+                conbus_protocol=self.container.resolve(ConbusEventProtocol)
             ),
             scope=punq.Scope.singleton,
         )
@@ -358,6 +397,15 @@ class ServiceContainer:
             scope=punq.Scope.singleton,
         )
 
+        # Logging
+        self.container.register(
+            LoggerService,
+            factory=lambda: LoggerService(
+                logger_config=self.container.resolve(ConbusLoggerConfig),
+            ),
+            scope=punq.Scope.singleton,
+        )
+
         # Module type services layer
         self.container.register(ModuleTypeService, scope=punq.Scope.singleton)
 
