@@ -10,10 +10,10 @@ from xp.services.conbus.actiontable.msactiontable_service import (
 
 
 class TestXp20ActionTableIntegration:
-    """Integration tests for XP20 Action Table"""
+    """Integration tests for XP20 Action Table."""
 
     def test_serializer_service_integration(self):
-        """Test that serializer works with service"""
+        """Test that serializer works with service."""
         # Create a sample action table
         action_table = Xp20MsActionTable()
         action_table.input1.invert = True
@@ -33,16 +33,8 @@ class TestXp20ActionTableIntegration:
         # Serialize it
         serialized = Xp20MsActionTableSerializer.to_data(action_table)
 
-        # Create mock telegram data
-        mock_telegram = (
-            "0123456789ABCDEF"  # 16 chars header
-            "AAAA"
-            + serialized  # 4 chars count + 64 chars data
-            + "PADDING"  # Additional padding
-        )
-
-        # Test legacy from_telegrams method
-        result = Xp20MsActionTableSerializer.from_telegrams(mock_telegram)
+        # Deserialize from data
+        result = Xp20MsActionTableSerializer.from_data(serialized)
 
         # Verify the round-trip worked
         assert result.input1.invert == action_table.input1.invert
@@ -51,15 +43,24 @@ class TestXp20ActionTableIntegration:
         assert result.input2.and_functions == action_table.input2.and_functions
 
     def test_service_xp20_support(self):
-        """Test that MsActionTableService recognizes XP20 module type"""
+        """Test that MsActionTableService recognizes XP20 module type."""
         # This test verifies the service is configured to handle xp20
         # without actually making network calls
         from unittest.mock import Mock
 
-        mock_conbus = Mock()
+        mock_cli_config = Mock()
+        mock_reactor = Mock()
+        mock_xp20_serializer = Mock()
+        mock_xp24_serializer = Mock()
+        mock_xp33_serializer = Mock()
         mock_telegram = Mock()
+
         service = MsActionTableService(
-            conbus_service=mock_conbus,
+            cli_config=mock_cli_config,
+            reactor=mock_reactor,
+            xp20ms_serializer=mock_xp20_serializer,
+            xp24ms_serializer=mock_xp24_serializer,
+            xp33ms_serializer=mock_xp33_serializer,
             telegram_service=mock_telegram,
         )
 
@@ -69,10 +70,11 @@ class TestXp20ActionTableIntegration:
 
         # Check that the service can be instantiated
         assert service is not None
-        assert service.conbus_service is not None
+        assert service.xp20ms_serializer is not None
+        assert service.telegram_service is not None
 
     def test_complex_configuration_round_trip(self):
-        """Test complex configuration through full serialization cycle"""
+        """Test complex configuration through full serialization cycle."""
         # Create a complex action table
         action_table = Xp20MsActionTable()
 
@@ -115,7 +117,7 @@ class TestXp20ActionTableIntegration:
             ), f"input{i} and_functions mismatch"
 
     def test_boundary_conditions(self):
-        """Test boundary conditions and edge cases"""
+        """Test boundary conditions and edge cases."""
         # Test all flags off
         action_table_off = Xp20MsActionTable()
         serialized_off = Xp20MsActionTableSerializer.to_data(action_table_off)
@@ -154,9 +156,9 @@ class TestXp20ActionTableIntegration:
             assert all(f for f in channel.and_functions)
 
     def test_specification_compliance(self):
-        """Test compliance with the specification example"""
+        """Test compliance with the specification example."""
         spec_example = (
-            "AAAAAAAAAAABACAEAIBACAEAIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
+            "AAAAAAAAAAAAAAABACAEAIBACAEAIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
         )
 
         # Should decode without errors
@@ -167,14 +169,14 @@ class TestXp20ActionTableIntegration:
 
         # Test that we can re-encode it
         re_encoded = Xp20MsActionTableSerializer.to_data(result)
-        assert len(re_encoded) == 64
+        assert len(re_encoded) == 68
 
         # Round-trip should work
         final_result = Xp20MsActionTableSerializer.from_data(re_encoded)
         assert isinstance(final_result, Xp20MsActionTable)
 
     def test_data_layout_compliance(self):
-        """Test that data layout matches specification"""
+        """Test that data layout matches specification."""
         action_table = Xp20MsActionTable()
 
         # Set specific inputs to test bit positions
@@ -238,7 +240,7 @@ class TestXp20ActionTableIntegration:
         ]
 
     def test_error_handling_integration(self):
-        """Test error handling across the integration"""
+        """Test error handling across the integration."""
         # Test invalid data length
         with pytest.raises(ValueError):
             Xp20MsActionTableSerializer.from_data("INVALID")
@@ -251,7 +253,7 @@ class TestXp20ActionTableIntegration:
             Xp20MsActionTableSerializer.from_data("A" * 65)  # Too long
 
     def test_model_serializer_consistency(self):
-        """Test that model defaults work correctly with serializer"""
+        """Test that model defaults work correctly with serializer."""
         # Default model should serialize and deserialize consistently
         default_table = Xp20MsActionTable()
         serialized = Xp20MsActionTableSerializer.to_data(default_table)
