@@ -1,4 +1,4 @@
-"""Tests for DiscoverService"""
+"""Tests for DiscoverService."""
 
 from unittest.mock import Mock
 
@@ -12,17 +12,17 @@ from xp.services.telegram.telegram_discover_service import (
 
 
 class TestDeviceInfo:
-    """Test cases for DeviceInfo class"""
+    """Test cases for DeviceInfo class."""
 
     def test_init(self):
-        """Test DeviceInfo initialization"""
+        """Test DeviceInfo initialization."""
         device = DeviceInfo("0012345011")
         assert device.serial_number == "0012345011"
         assert device.checksum_valid is True
         assert device.raw_telegram == ""
 
     def test_init_with_all_params(self):
-        """Test DeviceInfo initialization with all parameters"""
+        """Test DeviceInfo initialization with all parameters."""
         device = DeviceInfo(
             "0012345011", checksum_valid=False, raw_telegram="<R0012345011F01DFM>"
         )
@@ -31,7 +31,7 @@ class TestDeviceInfo:
         assert device.raw_telegram == "<R0012345011F01DFM>"
 
     def test_str_representation(self):
-        """Test string representation"""
+        """Test string representation."""
         device_valid = DeviceInfo("0012345011", checksum_valid=True)
         device_invalid = DeviceInfo("0012345011", checksum_valid=False)
 
@@ -39,12 +39,12 @@ class TestDeviceInfo:
         assert str(device_invalid) == "Device 0012345011 (✗)"
 
     def test_repr(self):
-        """Test repr representation"""
+        """Test repr representation."""
         device = DeviceInfo("0012345011", checksum_valid=False)
         assert repr(device) == "DeviceInfo(serial='0012345011', checksum_valid=False)"
 
     def test_to_dict(self):
-        """Test dictionary conversion"""
+        """Test dictionary conversion."""
         result = DeviceInfo(
             "0012345011", checksum_valid=True, raw_telegram="<R0012345011F01DFM>"
         ).to_dict()
@@ -58,20 +58,20 @@ class TestDeviceInfo:
 
 
 class TestDiscoverService:
-    """Test cases for DiscoverService"""
+    """Test cases for DiscoverService."""
 
     def test_init(self):
-        """Test initialization"""
+        """Test initialization."""
         service = TelegramDiscoverService()
         assert isinstance(service, TelegramDiscoverService)
 
     def test_generate_discover_telegram(self):
-        """Test generating discover broadcast telegram"""
+        """Test generating discover broadcast telegram."""
         result = TelegramDiscoverService().generate_discover_telegram()
         assert result == "<S0000000000F01D00FA>"
 
     def test_create_discover_telegram_object(self):
-        """Test creating SystemTelegram object for discover"""
+        """Test creating SystemTelegram object for discover."""
         telegram = TelegramDiscoverService().create_discover_telegram_object()
 
         assert isinstance(telegram, SystemTelegram)
@@ -82,7 +82,7 @@ class TestDiscoverService:
         assert telegram.raw_telegram == "<S0000000000F01D00FA>"
 
     def test_is_discover_response(self):
-        """Test identifying discover responses"""
+        """Test identifying discover responses."""
         service = TelegramDiscoverService()
 
         # Create mock discover response
@@ -98,7 +98,7 @@ class TestDiscoverService:
         assert service.is_discover_response(other_reply) is False
 
     def test_get_unique_devices(self):
-        """Test filtering unique devices"""
+        """Test filtering unique devices."""
         service = TelegramDiscoverService()
 
         devices = [
@@ -118,7 +118,7 @@ class TestDiscoverService:
         assert "0012345003" in serials
 
     def test_validate_discover_response_format_valid(self):
-        """Test validating valid discover response format"""
+        """Test validating valid discover response format."""
         service = TelegramDiscoverService()
 
         valid_telegrams = [
@@ -132,7 +132,7 @@ class TestDiscoverService:
             assert service.validate_discover_response_format(telegram) is True
 
     def test_validate_discover_response_format_invalid(self):
-        """Test validating invalid discover response format"""
+        """Test validating invalid discover response format."""
         service = TelegramDiscoverService()
 
         invalid_telegrams = [
@@ -150,7 +150,7 @@ class TestDiscoverService:
             assert service.validate_discover_response_format(telegram) is False
 
     def test_generate_discover_summary(self):
-        """Test generating discover summary"""
+        """Test generating discover summary."""
         service = TelegramDiscoverService()
 
         devices = [
@@ -174,7 +174,7 @@ class TestDiscoverService:
         assert len(result["device_list"]) == 3  # Only valid devices
 
     def test_generate_discover_summary_empty(self):
-        """Test generating summary for empty device list"""
+        """Test generating summary for empty device list."""
         result = TelegramDiscoverService().generate_discover_summary([])
 
         assert result["total_responses"] == 0
@@ -187,12 +187,12 @@ class TestDiscoverService:
         assert result["device_list"] == []
 
     def test_format_discover_results_empty(self):
-        """Test formatting results for empty device list"""
+        """Test formatting results for empty device list."""
         result = TelegramDiscoverService().format_discover_results([])
         assert result == "No devices discovered"
 
     def test_format_discover_results_with_devices(self):
-        """Test formatting results with devices"""
+        """Test formatting results with devices."""
         service = TelegramDiscoverService()
 
         devices = [
@@ -213,7 +213,7 @@ class TestDiscoverService:
         assert "0012xxxx: 3 device(s)" in result
 
     def test_format_discover_results_with_duplicates(self):
-        """Test formatting results with duplicate devices"""
+        """Test formatting results with duplicate devices."""
         service = TelegramDiscoverService()
 
         devices = [
